﻿using System;
using System.Collections.Generic;
using System.Web.UI;
using System.Configuration;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WebEdition;

namespace Post6320
{
    public partial class _Default : System.Web.UI.Page
    {
        #region private class
        class fieldInfo
        {
            public long typeMarker { get; set; }
            public string name { get; set; }
            public string geometry { get; set; }
        }
        static class fieldFactory
        {
            public static List<fieldInfo> getFields()
            {
                List<fieldInfo> liste = new List<fieldInfo>();

                //string geometryComplex = "MULTIPOLYGON(((1.51180028894361 43.5568680253015,1.50928974130602 43.5550797283494,1.51004075983009 43.5545043519587,1.5099334714695 43.5535557464553,1.5104699132724 43.553306929425,1.51102781274742 43.5542244371336,1.51360273340137 43.553306929425,1.51491165140045 43.5559661082546,1.51570558526875 43.5565881214557,1.51302337625423 43.5575366792255,1.51420354822062 43.5566192219472,1.51413917520426 43.5564637193292,1.51287317254941 43.5563704175657,1.51180028894361 43.5568680253015)))";
                liste.Add(new fieldInfo { typeMarker = 1, name = "Field <b>one</b>", geometry = "POINT(1.51250839212344 43.5552663357287)" });
                //liste.Add(new fieldInfo { typeMarker = 1, name = "Field <b>one</b>", geometry = geometryComplex});
                liste.Add(new fieldInfo { typeMarker = 2, name = "Field <b>two</b>", geometry = "POINT(1.524524688508 43.5662129572594)" });
                //liste.Add(new fieldInfo { typeMarker = 3, name = "Field <b>three</b>", geometry = "POINT(1.54529571511561 43.5653422760853)" });
                //liste.Add(new fieldInfo { typeMarker = 4, name = "Field <b>four</b>", geometry = "POINT(1.54306411721562 43.5517829026988)" });

                return liste;
            }
        }
        #endregion

        protected void Page_Load(object sender, EventArgs e)
        {
            if (!Page.IsPostBack)
            {
                InitializeModuleCarto();
                InitializeMarkers();
            }
        }

        #region Module Carto Initialisation

        private void InitializeModuleCarto()
        {
            InitializeMapAppearance();
            //InitializeBackgroundLayer();
            InitializeMapExtend();
            Map1.MapUnit = GeographyUnit.Meter;
        }

        private void InitializeMapAppearance()
        {
            Map1.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.FromHtml("#B3C6D4"));
            Map1.MapTools.OverlaySwitcher.Enabled = false;
            Map1.MapTools.MouseCoordinate.Enabled = true;
            Map1.MapTools.PanZoomBar.Enabled = true;
            Map1.MapTools.ScaleLine.Enabled = true;
            Map1.MapTools.Logo.Enabled = true;
        }

        private void InitializeBackgroundLayer()
        {
            GoogleOverlay gOverlay = new GoogleOverlay();
            gOverlay.Name = "Google Overlay";
            gOverlay.GoogleMapType = GoogleMapType.Hybrid;

            string sOverlayMapURL = ConfigurationManager.AppSettings["GoogleUri"];

            gOverlay.JavaScriptLibraryUri = new Uri(sOverlayMapURL);
            Map1.BackgroundOverlay = gOverlay;

        }

        private void InitializeMapExtend()
        {
            //Map1.CurrentExtent = new RectangleShape("POLYGON((165791.914327469 5404250.77306625,184442.549226456 5404250.77306625,184442.549226456 5391944.41151405,165791.914327469 5391944.41151405,165791.914327469 5404250.77306625))");
        }


        private BaseShape ProjectGeometry(BaseShape shapeIn, string projIn, string projOut)
        {
            Proj4Projection proj4 = new Proj4Projection();

            proj4.InternalProjectionParametersString = projIn;
            proj4.ExternalProjectionParametersString = projOut;
            proj4.Open();

            BaseShape shapeOut = proj4.ConvertToExternalProjection(shapeIn);

            proj4.Close();
            return shapeOut;
        }

        #endregion

        private void InitializeMarkers()
        {
            ValueMarkerStyle valueStyle = new ValueMarkerStyle("MARKERTYPE");

            PointMarkerStyle markerStyle1 = new PointMarkerStyle(new WebImage("../theme/default/img/marker.gif"));
            markerStyle1.Popup.ContentHtml = "<div>the field is:[#MARKERNAME#]</div>";
            markerStyle1.Popup.Width = 60;
            markerStyle1.Popup.Height = 60;
            markerStyle1.Popup.IsVisible = false;

            PointMarkerStyle markerStyle2 = new PointMarkerStyle(new WebImage("../theme/default/img/marker_blue.gif"));
            markerStyle2.Popup.ContentHtml = "<div>the field is:[#MARKERNAME#]</div>";
            markerStyle2.Popup.Width = 60;
            markerStyle2.Popup.Height = 60;
            markerStyle2.Popup.IsVisible = false;

            valueStyle.ValueItems.Add(new MarkerValueItem("1", markerStyle1));
            valueStyle.ValueItems.Add(new MarkerValueItem("2", markerStyle2));

            Map1.MarkerOverlay.ZoomLevelSet.ZoomLevel01.CustomMarkerStyle = valueStyle;
            Map1.MarkerOverlay.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            Map1.MarkerOverlay.FeatureSource.Open();
            Map1.MarkerOverlay.Columns.Add(new FeatureSourceColumn("MARKERTYPE"));
            Map1.MarkerOverlay.Columns.Add(new FeatureSourceColumn("MARKERNAME"));
            AppendFeatures();
            Map1.MarkerOverlay.FeatureSource.Close();
        }

        private void AppendFeatures()
        {
            List<fieldInfo> listeField = fieldFactory.getFields();
            List<string> listWKT = new List<string>();

            foreach (fieldInfo field in listeField)
            {
                BaseShape bs = BaseShape.CreateShapeFromWellKnownData(field.geometry);
                BaseShape bs2 = ProjectGeometry(bs, Proj4Projection.GetEpsgParametersString(4326), Proj4Projection.GetGoogleMapParametersString());

                Feature feature = bs.GetFeature();
                feature.ColumnValues.Add("MARKERTYPE", field.typeMarker.ToString());
                feature.ColumnValues.Add("MARKERNAME", field.name);

                Map1.MarkerOverlay.Features.Add(feature);
            }
        }
    }
}
